Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: net/proxy/proxy_service_mojo.h

Issue 910343003: Create an in-process v8 proxy resolver using Mojo. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@v8-pac-complete-patch
Patch Set: Remove extra space. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/proxy_resolver_mojo_unittest.cc ('k') | net/proxy/proxy_service_mojo.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_service_mojo.h
diff --git a/net/proxy/proxy_service_v8.h b/net/proxy/proxy_service_mojo.h
similarity index 59%
copy from net/proxy/proxy_service_v8.h
copy to net/proxy/proxy_service_mojo.h
index 0e339ebf3e76bf690e1ee50838de33d948760a6c..dcaee6aa0677b7ce1b15ab78b13c20ea99f2a3f8 100644
--- a/net/proxy/proxy_service_v8.h
+++ b/net/proxy/proxy_service_mojo.h
@@ -1,25 +1,27 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_PROXY_PROXY_SERVICE_V8_H_
-#define NET_PROXY_PROXY_SERVICE_V8_H_
+#ifndef NET_PROXY_PROXY_SERVICE_MOJO_H_
+#define NET_PROXY_PROXY_SERVICE_MOJO_H_
#include "base/basictypes.h"
-#include "net/base/net_export.h"
namespace net {
class DhcpProxyScriptFetcher;
class HostResolver;
+class MojoProxyResolverFactory;
class NetLog;
class NetworkDelegate;
class ProxyConfigService;
class ProxyScriptFetcher;
class ProxyService;
// Creates a proxy service that polls |proxy_config_service| to notice when
// the proxy settings change. We take ownership of |proxy_config_service|.
//
// |proxy_script_fetcher| specifies the dependency to use for downloading
// any PAC scripts. The resulting ProxyService will take ownership of it.
@@ -31,13 +33,24 @@ class ProxyService;
// |host_resolver| points to the host resolving dependency the PAC script
// should use for any DNS queries. It must remain valid throughout the
// lifetime of the ProxyService.
+ProxyService* CreateProxyServiceUsingMojoFactory(
+ MojoProxyResolverFactory* mojo_proxy_factory,
+ ProxyConfigService* proxy_config_service,
+ ProxyScriptFetcher* proxy_script_fetcher,
+ DhcpProxyScriptFetcher* dhcp_proxy_script_fetcher,
+ HostResolver* host_resolver,
+ NetLog* net_log,
+ NetworkDelegate* network_delegate);
+
+// Creates a proxy service that connects to an in-process Mojo proxy resolver
+// service. See above for information about other arguments.
//
// ##########################################################################
// # See the warnings in net/proxy/proxy_resolver_v8.h describing the
// # multi-threading model. In order for this to be safe to use, *ALL* the
// # other V8's running in the process must use v8::Locker.
// ##########################################################################
-NET_EXPORT ProxyService* CreateProxyServiceUsingV8ProxyResolver(
+ProxyService* CreateProxyServiceUsingMojoInProcess(
ProxyConfigService* proxy_config_service,
ProxyScriptFetcher* proxy_script_fetcher,
DhcpProxyScriptFetcher* dhcp_proxy_script_fetcher,
@@ -47,4 +60,4 @@ NET_EXPORT ProxyService* CreateProxyServiceUsingV8ProxyResolver(
} // namespace net
-#endif // NET_PROXY_PROXY_SERVICE_V8_H_
+#endif // NET_PROXY_PROXY_SERVICE_MOJO_H_
« no previous file with comments | « net/proxy/proxy_resolver_mojo_unittest.cc ('k') | net/proxy/proxy_service_mojo.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -1,25 +1,27 @@
class ProxyScriptFetcher;
class ProxyService;
-// Creates a proxy service that polls |proxy_config_service| to notice when
-// the proxy settings change. We take ownership of |proxy_config_service|.
+// Creates a proxy service that uses |mojo_proxy_factory| to create and connect
+// to a Mojo proxy resolver service. This proxy service polls
+// |proxy_config_service| to notice when the proxy settings change. We take
+// ownership of |proxy_config_service|.
//
// |proxy_script_fetcher| specifies the dependency to use for downloading
This is Rietveld 408576698